@@ -27,7 +27,16 @@
 # everywhere we change the tracklist
 # we use this in autoplayergui to update the tracklist
 
-import sys, time, thread
+from __future__ import division
+from __future__ import print_function
+from __future__ import absolute_import
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
+from builtins import object
+from past.utils import old_div
+import sys, time, _thread
+import tempfile,os
 
 #import pygst
 #pygst.require("0.10")
@@ -38,7 +47,7 @@ import gi
 gi.require_version('Gst', '1.0')
 from gi.repository import GObject, Gst
 
-import playlist
+from . import playlist
 import dbus
 import dbus.service
 import dbus.mainloop.glib
@@ -351,7 +360,7 @@ class AutoPlayer(dbus.service.Object):
     def GetAll(self, interface):
         read_props = {}
         props = self.__prop_mapping[interface]
-        for key, (getter, setter) in props.iteritems():
+        for key, (getter, setter) in props.items():
             if callable(getter):
                 getter = getter(self)
             read_props[key] = getter
@@ -418,7 +427,7 @@ class AutoPlayer(dbus.service.Object):
 
     @dbus.service.method(PLAYER_IFACE)
     def Next(self):
-      self.player.next()
+      next(self.player)
 
     @dbus.service.method(PLAYER_IFACE)
     def Previous(self):
@@ -507,10 +516,14 @@ class AutoPlayer(dbus.service.Object):
           if id is not None:
             meta={}
             for key,attr in ("mpris:trackid","id"),("mpris:length","time"),("xesam:title","title"),("xesam:artist","artist"),("xesam:url","path"):
-              myattr= getattr(self.player.playlist[id],attr,None)
+              try:
+                myattr= getattr(self.player.playlist.get(id,None),attr,None)
+              except:
+                #very very strange to go here but it happen
+                myattr=None
               if myattr is not None:
                 if key == "mpris:length":
-                  myattr=long(round(myattr/1000.))
+                  myattr=int(round(old_div(myattr,1000.)))
                 meta[key]=myattr
       
             metadata.append(dbus.Dictionary(meta, signature='sv'))
@@ -531,7 +544,7 @@ class AutoPlayer(dbus.service.Object):
       self.Quit()
 
 
-class Player:
+class Player(object):
 	
   def __init__(self,myplaylist=None,loop=None,starttoplay=False,myaudiosink=None):
     self.playlist=myplaylist
@@ -690,7 +703,7 @@ class Player:
     #self.player.set_state(Gst.State.NULL)      
     #self.playmode = "Stopped"
     #self.statuschanged = True
-    self.next()
+    next(self)
 
   def on_message_error(self, bus, message):
 
@@ -706,7 +719,7 @@ class Player:
     logging.warning("current media: %s" % currenturi)
 
     self.playmode= self.recoverplaymode
-    self.next()
+    next(self)
     
 #    if err.domain == gst.RESOURCE_ERROR :
 #      logging.warning("restart to play after an RESOURCE_ERROR")
@@ -751,9 +764,9 @@ class Player:
           self.playmode = "Playing"
           self.statuschanged = True
 
-  def next(self):
+  def __next__(self):
       logging.info( "next")
-      self.playlist.next()
+      next(self.playlist)
       if self.playlist.current is None:
           logging.info( "end playlist")
           self.stop()
@@ -799,7 +812,7 @@ class Player:
     logging.info("seek")
     try:
       pos_int = self.player.query_position(Gst.Format.TIME)[1]
-      pos_int =pos_int/1000 + t
+      pos_int =old_div(pos_int,1000) + t
       logging.info("seek %s" % str(pos_int))
       self.setposition(self.playlist.current,pos_int)
       return pos_int
@@ -830,7 +843,7 @@ class Player:
         res = self.player.send_event(event)
         if res:
           #self.player.set_new_stream_time(0L)
-          self.player.set_start_time(0L)
+          self.player.set_start_time(0)
         #if wait: self.playbin.get_state(timeout=50*gst.MSECOND)
 
         # this cause a doble seek with playbin2
@@ -843,8 +856,8 @@ class Player:
     logging.info( "loaduri")
 
     if self.playlist.current is None:
-      if len(self.playlist.keys()) > 0:
-        self.playlist.set_current(self.playlist.keys()[0])
+      if len(list(self.playlist.keys())) > 0:
+        self.playlist.set_current(list(self.playlist.keys())[0])
 
     uri = self.playlist.get_current().path
     if uri is not None:
@@ -858,22 +871,22 @@ class Player:
 
   def play(self):
     logging.info( "play")
+    self.recoverplaymode = "Playing"
     ret = self.player.set_state(Gst.State.PLAYING)
     #if ret == Gst.State.CHANGE_FAILURE:
     if ret == Gst.StateChangeReturn.FAILURE:
         logging.error( "Unable to set the pipeline to the PLAYING state.")
-        self.recoverplaymode = "Playing"
 
     #else:
     #  print self.player.get_state(timeout=gst.CLOCK_TIME_NONE)
 
   def pause(self):
     logging.info( "pause")
+    self.recoverplaymode = "Paused"
     ret = self.player.set_state(Gst.State.PAUSED)
     #if ret == Gst.State.CHANGE_FAILURE:
     if ret == Gst.StateChangeReturn.FAILURE:
         logging.error( "Unable to set the pipeline to the PAUSED state.")
-        self.recoverplaymode = "Paused"
     #else:
     #  print self.player.get_state(timeout=gst.CLOCK_TIME_NONE)
 
@@ -892,13 +905,12 @@ class Player:
 
   def stop(self):
     logging.info( "stop")
-
+    self.recoverplaymode = "Stopped"
     #self.loaduri()
     ret = self.player.set_state(Gst.State.READY)
     #if ret == Gst.State.CHANGE_FAILURE:
     if ret == Gst.StateChangeReturn.FAILURE:
       logging.error( "Unable to set the pipeline to the READY state.")
-      self.recoverplaymode = "Stopped"
 
     #else:
     #  print self.player.get_state(timeout=gst.CLOCK_TIME_NONE)
@@ -916,7 +928,7 @@ class Player:
       logging.warning( "in query_position:"+str(e) )
       return None
 			    
-    return int(round(pos_int/1000.))
+    return int(round(old_div(pos_int,1000.)))
 
 
   def printinfo(self):
@@ -925,7 +937,7 @@ class Player:
       dur_int = self.player.query_duration(Gst.Format.TIME)[1]
       #      if dur_int == -1:
       #        print "bho"
-      print self.playmode,self.convert_ns(pos_int)+"//"+self.convert_ns(dur_int)
+      print(self.playmode,self.convert_ns(pos_int)+"//"+self.convert_ns(dur_int))
 
     except(Gst.QueryError):
         #print "error printinfo"
@@ -942,10 +954,22 @@ class Player:
       self.playlist.position=self.position()*1000
 
     try:
-      self.playlist.write(path)
+
+      fd,tmpfile=tempfile.mkstemp(dir=os.path.dirname(os.path.abspath(path)))
+      self.playlist.write(tmpfile)
+      os.close(fd)   #see at https://www.logilab.org/blogentry/17873
+      #if os.path.exists(path):
+      #  os.unlink(path)
+      os.rename(tmpfile, path)
+
     except:
       logging.error( "error saving playlist")
       raise
+
+    finally:
+      if os.path.exists(tmpfile):
+        os.unlink(tmpfile)
+
     logging.info ( "playlist saved %s" % path)
     return True
 
@@ -965,8 +989,8 @@ class Player:
     time.sleep(1)
     logging.info ( "recover last status from disk: position %s" % self.playlist.position)
     if self.playlist.position is not None:
-      logging.info ( "set current %s and position %s " % (self.playlist.current,int(round(self.playlist.position/1000.))))
-      self.setposition(self.playlist.current,int(round(self.playlist.position/1000.)))
+      logging.info ( "set current %s and position %s " % (self.playlist.current,int(round(old_div(self.playlist.position,1000.)))))
+      self.setposition(self.playlist.current,int(round(old_div(self.playlist.position,1000.))))
     if self.starttoplay:
       time.sleep(1)
       self.play()
@@ -1005,6 +1029,7 @@ class Player:
 
   def exit(self):
     logging.info("save playlist: %s" % STATUS_PLAYLIST )
+
     self.save_playlist(STATUS_PLAYLIST)
     self.stop()
     self.loop.quit()
