@@ -38,9 +38,9 @@ class schedule(object):
         """
         init of schedule object:
         """
-        self.djobj=djobj
+        self.mydjobj=djobj
         self.scheduledatetime=scheduledatetime
-        self.media=media
+        self.mymedia=media
         self.filename=filename
         #self.mediaweb = self.media[len(settings.MEDIA_URL)+1:]
         self.length=length
@@ -48,30 +48,32 @@ class schedule(object):
         self.emission_done=emission_done
         self.shuffle=shuffle
         self.maxlength=maxlength
-        self.title=title
+        self.mytitle=title
 
-    def __cmp__ (self, b):
 
-        if self.scheduledatetime is None and b.scheduledatetime is None :
-            return 0
-    
-        if self.scheduledatetime is None :
-            return -1
-    
-        if b.scheduledatetime is None :
-            return 1
-    
+    def __eq__(self, other):
+        if (self.scheduledatetime is None and other.scheduledatetime is None
+            or self.scheduledatetime == other.scheduledatetime) :
+            return True
 
-        if  self.scheduledatetime == b.scheduledatetime :
-            return 0
-        elif   self.scheduledatetime < b.scheduledatetime :
-            return -1
-        elif    self.scheduledatetime > b.scheduledatetime :
-            return 1
+    def __ne__(self, other):
+        return not self.__eq__(self, other)
 
+    def __lt__(self, other):
+        return self.scheduledatetime < other.scheduledatetime
+
+    def __le__(self, other):
+        return self.scheduledatetime <= other.scheduledatetime
+
+    def __gt__(self, other):
+        return self.scheduledatetime > other.scheduledatetime
+
+    def __ge__(self, other):
+        return self.scheduledatetime >= other.scheduledatetime
+
+        
     def future (self,now=None):
-        self.future=self.scheduledatetime > now
-        return self.future
+        return self.scheduledatetime > now
 
     def filter (self):
 
@@ -80,31 +82,64 @@ class schedule(object):
 
         return True
 
-    def __str__ (self):
+    def __repr__ (self):
 
-        return self.type+" "+self.media
+        return self.type+" "+self.mymedia
 
 
-    def __iter__(self,now=None):
-        '''
-        return a list  nome,datet,media,len,tipo,datetdone,future 
-        '''
+#    def __iter__(self,now=None):
+#        self.index=0
+#        self.now=now
+#        if self.now is None : self.now=datetime.now()
+#        return self
+#        
+#    def __next__(self):
+#        self.index+=1
+#        if (self.index==1):
+#            return self.mydjobj
+#        if (self.index==2):
+#            return self.mytitle
+#        if (self.index==3):
+#            return self.scheduledatetime
+#        if (self.index==4):
+#            return self.mymedia
+#        if (self.index==5):
+#            return str((datetime(2000,1,1)+timedelta(seconds=int(self.length))).time())
+#        if (self.index==6):
+#            return self.type
+#        if (self.index==7):
+#            return self.emission_done
+#        if (self.index==8):
+#            return self.future(self.now)
+#        raise StopIteration
 
-        if now is None : now=datetime.now()
-
-        #return iter((self.djobj,self.scheduledatetime,self.media,self.length,self.type,\
-        # self.emission_done,self.shuffle,self.future(now)))
-
-        yield self.djobj
-        yield self.title
-        yield self.scheduledatetime
-        yield self.media
-        yield str((datetime(2000,1,1)+timedelta(seconds=int(self.length))).time())
-        yield self.type
-        yield self.emission_done
-        yield self.future(now)
+    def get_djobj(self):
+        return self.mydjobj
+    def get_title(self):
+        return self.mytitle
+    def get_datet(self):
+        return self.scheduledatetime
+    def get_media(self):
+        return self.mymedia
+    def get_length_s(self):
+        return str((datetime(2000,1,1)+timedelta(seconds=int(self.length))).time())
+    def get_tipo(self):
+        return self.type        
+    def get_datetdone(self):
+        return self.emission_done
+    def get_isfuture(self):
+        return self.future(datetime.now())
 
+    djobj=property(get_djobj)
+    title=property(get_title)
+    datet=property(get_datet)
+    media=property(get_media)
+    length_s=property(get_length_s)
+    tipo=property(get_tipo)
+    datetdone=property(get_datetdone)
+    isfuture=property(get_isfuture)
 
+    
 class schedules(list):
     """
     multiple schedule object
@@ -393,7 +428,7 @@ class schedules(list):
                                      emission_done,title=str(jingle)))
 
 
-        return self
+        #return self
 
 
     def get_all_refine(self,now=None,genfile=True):
@@ -404,8 +439,8 @@ class schedules(list):
             pass
         self.purge()
         self.sort()
-
-        return self
+        
+        #return self
 
 
 
@@ -475,22 +510,33 @@ class palimpsest(object):
             str(self.datetime_end)+" "+str(self.type)+" "+\
             str(self.subtype)+" "+str(self.production)+" "+str(self.note)
 
-
+    
     def __iter__(self):
         '''
         return a list
         '''
+        self.index=0
+        return self
 
-        yield self.title
-        yield self.datetime_start
-        yield self.datetime_end
-        yield self.code
-        yield self.type
-        yield self.subtype
-        yield self.production
-        yield self.note
-
-
+    def __next__(self):
+        self.index+=1
+        if (self.index==1):
+            return self.title
+        if (self.index==2):
+            return self.datetime_start
+        if (self.index==3):
+            return self.datetime_end
+        if (self.index==4):
+            return self.code
+        if (self.index==5):
+            return self.type
+        if (self.index==6):
+            return self.subtype
+        if (self.index==7):
+            return self.production
+        if (self.index==8):
+            return self.note
+        raise StopIteration
 
 class dates(object):
 
@@ -513,6 +559,7 @@ class dates(object):
             return self.datetime_start
         else:
             raise StopIteration
+            #return
 
 
 class palimpsests(list):
@@ -550,9 +597,9 @@ class palimpsests(list):
 
         self.sort()
 
-        #print "prima:"
+        #print ("prima:")
         #for program in self:
-        #    print program
+        #    print (program)
 
         # timing adjust:
         #    1) overlay
