@@ -1,3 +1,4 @@
+from __future__ import print_function
 class Uri(str):
     '''A unique resource identifier.'''
     def __init__(self, uri, *args, **kw):
@@ -9,4 +10,4 @@ class Uri(str):
         return self._uri
     
 if __name__ == "__main__":
-    print Uri('http://www.com.br')
\ No newline at end of file
+    print(Uri('http://www.com.br'))
\ No newline at end of file
