@@ -38,7 +38,7 @@ class MySelectDateWidget(Widget):
             this_year = datetime.date.today().year-9
             self.years = list(range(this_year, this_year+10))
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
 
         try:
             year_val, month_val, day_val = value.year, value.month, value.day
@@ -59,7 +59,7 @@ class MySelectDateWidget(Widget):
         day_choices = [(i, i) for i in range(1, 32)]
         if not (self.required and value):
             day_choices.insert(0, self.none_value)
-        local_attrs = self.build_attrs(id=self.day_field % id_)
+        local_attrs = self.build_attrs(base_attrs={'id':self.day_field % id_})
         
         s = Select(choices=day_choices)
         select_html = s.render(self.day_field % name, day_val, local_attrs)
