@@ -22,7 +22,7 @@ urlpatterns = [
     url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
 
 #    Uncomment the next line to enable the admin:
-    url(r'^admin/', include(admin.site.urls)),
+    url(r'^admin/', admin.site.urls),
 
     url(r'^', include('autoradio.programs.urls')),
 #    url(r'^', include('autoradio.palimpsest.urls')),
